@@ -9,7 +9,7 @@ pitkat = ['yi', 'öi', 'äi', 'ui', 'oi', 'ai', 'äy', 'au', 'yö', 'öy', 'uo',
 			'aa', 'ii', 'uu', 'ee', 'oo', 'yy', 'ää', 'öö']			# suomen pitkät vokaalit ja diftongit
 pitkat = pitkat + [a.upper() for a in pitkat] + [a[0].upper()+a[1] for a in pitkat] + [a[0]+a[1].upper() for a in pitkat]
 
-def hyp_word(sana):
+def syllables(sana):
 	tavut = []
 	buff = ''					# parhaillaan tavu jota kursitaan kasaan, on buffissa.
 	rajakerake = None	
@@ -77,6 +77,15 @@ def hyp_word(sana):
 		tavut.append(buff)
 	return tavut
 
+def add_hyphens(tavut, sana, hyphen, margin):
+	tavutettava = ''
+	charcount = 0
+	for tavu in tavut:
+		tavutettava += tavu
+		charcount += len(tavu)
+		if charcount >= margin and charcount <= len(sana) - margin:
+			tavutettava += hyphen
+	return tavutettava
 
 def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 	"""hyphenate_finnish(text, margin=2, skip_html=False, hyphen='\u00AD')
@@ -108,23 +117,27 @@ def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 			if skip_html:
 				if not skipataan and "<" in sana:
 					skipataan = True
+					eka = sana.find('<')
+					tavutettava_osa = sana[:eka]
+					tavut = syllables(tavutettava_osa)
+					tavutettu = add_hyphens(tavut, tavutettava_osa, hyphen, margin)
+					sana = tavutettu + sana[eka:]
 		
 				if skipataan:
-					valmis_rivi.append(sana)
 					if ">" in sana and sana.rfind('>') > sana.rfind('<'):
 						skipataan = False
+						vika = sana.rfind('>')+1
+						tavutettava_osa = sana[vika:]
+						tavut = syllables(tavutettava_osa)
+						tavutettu = add_hyphens(tavut, tavutettava_osa, hyphen, margin)
+						sana = sana[:vika] + tavutettu
+					valmis_rivi.append(sana)
 					continue
 			
-			tavut = hyp_word(sana)
-	
-			tavutettava = ''
-			charcount = 0
-			for tavu in tavut:
-				tavutettava += tavu
-				charcount += len(tavu)
-				if charcount >= margin and charcount <= len(sana) - margin:
-					tavutettava += hyphen
-			valmis_rivi.append( tavutettava )
+			tavut = syllables(sana)
+			sana = add_hyphens(tavut, sana, hyphen, margin)
+
+			valmis_rivi.append( sana )
 			
 		valmis_rivi = ' '.join(valmis_rivi)
 		valmis_teksti.append(valmis_rivi)
